@@ -1,5 +1,5 @@
 package Elastic::Model::Index;
-$Elastic::Model::Index::VERSION = '0.28';
+$Elastic::Model::Index::VERSION = '0.50';
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Index';
@@ -13,8 +13,7 @@ sub create {
 #===================================
     my $self   = shift;
     my $params = $self->index_config(@_);
-
-    $self->es->create_index($params);
+    $self->model->store->create_index(%$params);
     return $self;
 }
 
@@ -70,21 +69,20 @@ sub reindex {
     my $updater = $self->doc_updater( $doc_updater, $uid_updater );
 
     my $source = $model->view->domain($domain)->size($size)->scan($scan);
-    $model->es->reindex(
-        source       => $source,
-        _method_name => 'shift_element',
-        quiet        => !$verbose,
-        transform    => $updater,
-        bulk_size    => $bulk_size,
-        on_conflict  => $args{on_conflict},
-        on_error     => $args{on_error},
+    $model->store->reindex(
+        source      => sub { $source->shift_element },
+        verbose     => $verbose,
+        transform   => $updater,
+        bulk_size   => $bulk_size,
+        on_conflict => $args{on_conflict},
+        on_error    => $args{on_error},
     );
 
     return 1 unless $args{repoint_uids};
 
     $self->repoint_uids(
         uids        => \%uids,
-        quiet       => !$verbose,
+        verbose     => $verbose,
         exclude     => [ keys %map ],
         size        => $size,
         bulk_size   => $bulk_size,
@@ -99,7 +97,7 @@ sub repoint_uids {
 #===================================
     my ( $self, %args ) = @_;
 
-    my $verbose    = !$args{quiet};
+    my $verbose    = $args{verbose};
     my $scan       = $args{scan} || '2m';
     my $size       = $args{size} || 1000;
     my $bulk_size  = $args{bulk_size} || $size;
@@ -143,33 +141,31 @@ sub repoint_uids {
 
     my $updater = $self->doc_updater( $doc_updater, $uid_updater );
 
-    local $| = $verbose;
-
     for my $index ( keys %$uids ) {
         my $types = $uids->{$index};
         for my $type ( keys %$types ) {
             my @ids = keys %{ $types->{$type} };
 
-            printf( "Repointing %d UIDs from %s/%s ",
+            printf( "Repointing %d UIDs from %s/%s\n",
                 0 + @ids, $index, $type )
                 if $verbose;
 
             while (@ids) {
-                print "." if $verbose;
 
                 my $clauses
                     = $self->_build_uid_clauses( \@uid_attrs, $index, $type,
                     [ splice @ids, 0, $size ] );
 
                 my $source = $view->filter( or => $clauses )->scan($scan);
-                $model->es->reindex(
-                    source       => $source,
-                    _method_name => 'shift_element',
-                    bulk_size    => $bulk_size,
-                    quiet        => 1,
-                    transform    => $updater,
-                    on_conflict  => $args{on_conflict},
-                    on_error     => $args{on_error},
+                $model->store->reindex(
+                    source => sub {
+                        $source->shift_element;
+                    },
+                    bulk_size   => $bulk_size,
+                    quiet       => 1,
+                    transform   => $updater,
+                    on_conflict => $args{on_conflict},
+                    on_error    => $args{on_error},
                 );
             }
             print "\n" if $verbose;
@@ -185,10 +181,10 @@ sub _uid_attrs_for_indices {
 #===================================
     my $self    = shift;
     my @indices = @_;
-    my $mapping = $self->model->es->mapping( index => \@indices );
+    my $mapping = $self->model->store->get_mapping( index => \@indices );
     my %attrs   = map { $_ => 1 }
         map { _find_uid_attrs( $_->{properties} ) }
-        map { values %$_ } values %$mapping;
+        map { values %{ $_->{mappings} } } values %$mapping;
     return keys %attrs;
 
 }
@@ -276,7 +272,7 @@ Elastic::Model::Index - Create and administer indices in Elasticsearch
 
 =head1 VERSION
 
-version 0.28
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -406,16 +402,17 @@ to convert the single-value C<tag> field to an array of C<tags>:
 
 =item on_conflict / on_error
 
-If you are indexing to the new index at the same time as you are reindexing,
-you may get document conflicts.  You can handle the conflicts with a coderef
-callback, or ignore them by by setting C<on_conflict> to C<'IGNORE'>:
+If you are indexing to the new index at the same time as you
+are reindexing, you may get document conflicts.  You can handle the conflicts
+with a coderef callback, or ignore them by by setting C<on_conflict> to
+C<'IGNORE'>:
 
     $index->reindex( 'myapp_v2', on_conflict => 'IGNORE' );
 
 Similarly, you can pass an C<on_error> handler which will handle other errors,
 or all errors if no C<on_conflict> handler is defined.
 
-See L<Search::Elasticsearch::Compat/Error handlers> for more.
+See L<Search::Elasticsearch::Bulk/Using-callbacks> for more.
 
 =item uid_on_conflict / uid_on_error
 
