@@ -1,10 +1,10 @@
 package Elastic::Model::Result;
-$Elastic::Model::Result::VERSION = '0.28';
+$Elastic::Model::Result::VERSION = '0.50';
 use Moose;
 
 use Carp;
 use Elastic::Model::Types qw(UID);
-use MooseX::Types::Moose qw(HashRef Maybe Num);
+use MooseX::Types::Moose qw(HashRef Maybe Num Bool);
 
 use namespace::autoclean;
 
@@ -16,6 +16,14 @@ has 'result' => (
     required => 1,
 );
 
+#===================================
+has 'is_partial' => (
+#===================================
+    isa      => Bool,
+    is       => 'ro',
+    required => 1,
+);
+
 #===================================
 has 'uid' => (
 #===================================
@@ -86,12 +94,19 @@ no Moose;
 
 #===================================
 sub _build_uid    { Elastic::Model::UID->new_from_store( shift()->result ) }
-sub _build_source { shift->result->{_source} }
 sub _build_score  { shift->result->{_score} }
 sub _build_fields { shift->result->{fields} || {} }
 sub _build_highlights { shift->result->{highlight} || {} }
 #===================================
 
+#===================================
+sub _build_source {
+#===================================
+    my $self = shift;
+    return undef if $self->is_partial;
+    return $self->result->{_source};
+}
+
 #===================================
 sub _build_object {
 #===================================
@@ -108,7 +123,7 @@ sub _build_partial {
     my $self = shift;
     $self->result->{_partial} ||= $self->model->new_partial_doc(
         uid            => Elastic::Model::UID->new_partial( $self->result ),
-        partial_source => $self->field('_partial_doc')
+        partial_source => $self->result->{_source}
     );
 }
 
@@ -173,7 +188,7 @@ Elastic::Model::Result - A wrapper for individual search results
 
 =head1 VERSION
 
-version 0.28
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -240,6 +255,13 @@ using L<Elastic::Model::View/"include_paths / exclude_paths">.
 The partial objects returned by L</partial> function exactly as real objects,
 except that they cannot be saved.
 
+=head2 is_partial
+
+    $bool = $result->is_partial;
+
+Return C<true> or C<false> to indicate whether the currently loaded
+C<_source> field is partial or not.
+
 =head2 highlights
 
 =head2 highlight
