@@ -1,5 +1,5 @@
 package Elastic::Model::Results::Scrolled;
-$Elastic::Model::Results::Scrolled::VERSION = '0.28';
+$Elastic::Model::Results::Scrolled::VERSION = '0.50';
 use Carp;
 use Moose;
 with 'Elastic::Model::Role::Results';
@@ -10,7 +10,7 @@ use namespace::autoclean;
 #===================================
 has '_scroll' => (
 #===================================
-    isa    => 'Search::Elasticsearch::Compat::ScrolledSearch',
+    isa    => 'Search::Elasticsearch::Scroll',
     is     => 'ro',
     writer => '_set_scroll',
 );
@@ -35,7 +35,8 @@ sub BUILD {
 
     $self->_set_total( $scroll->total );
     $self->_set_virtual_size( $scroll->total );
-    $self->_set_facets( $scroll->facets || {} );
+    $self->_set_facets( $scroll->facets       || {} );
+    $self->_set_aggs( $scroll->aggregations   || {} );
     $self->_set_max_score( $scroll->max_score || 0 );
 }
 
@@ -69,7 +70,7 @@ sub _fetch_until {
     my $i        = shift || 0;
     my $scroll   = $self->_scroll;
     my $elements = $self->elements;
-    while ( $i >= @$elements and not $scroll->eof ) {
+    while ( $i >= @$elements and not $scroll->is_finished ) {
         push @$elements, $scroll->drain_buffer;
         $scroll->refill_buffer;
     }
@@ -87,7 +88,7 @@ Elastic::Model::Results::Scrolled - An iterator over unbounded search results
 
 =head1 VERSION
 
-version 0.28
+version 0.50
 
 =head1 SYNOPSIS
 
