@@ -1,11 +1,9 @@
 package Elastic::Model::Role::Model;
-$Elastic::Model::Role::Model::VERSION = '0.28';
+$Elastic::Model::Role::Model::VERSION = '0.50';
 use Moose::Role;
 use Carp;
-use Elastic::Model::Types qw(ES ES_UniqueKey);
-use Search::Elasticsearch 1.10         ();
-use Search::Elasticsearch::Compat 0.10 ();
-use ElasticSearchX::UniqueKey 0.05     ();
+use Elastic::Model::Types qw(ES);
+use Search::Elasticsearch 1.12 ();
 use Class::Load qw(load_class);
 use Moose::Util qw(does_role);
 use MooseX::Types::Moose qw(:all);
@@ -22,6 +20,22 @@ my @wrapped_classes = qw(
     results cached_results scrolled_results result  bulk
 );
 
+#===================================
+sub BUILD {
+#===================================
+    my $self = shift;
+    my $es   = $self->es;
+    if ( $es->isa('Search::Elasticsearch::Client::0_90::Direct') ) {
+        $self->_set_result_class(
+            $self->_wrap_class('Elastic::Model::0_90::Result') );
+        $self->_set_store_class(
+            $self->_wrap_class('Elastic::Model::0_90::Store') );
+    }
+    $self->doc_class_wrappers;
+    return $self;
+
+}
+
 for my $class (@wrapped_classes) {
 #===================================
     has "${class}_class" => (
@@ -29,6 +43,7 @@ for my $class (@wrapped_classes) {
         isa     => Str,
         is      => 'ro',
         lazy    => 1,
+        writer  => "_set_${class}_class",
         default => sub { shift->wrap_class($class) }
     );
 }
@@ -69,12 +84,12 @@ has 'es' => (
 );
 
 #===================================
-has 'es_unique' => (
+has '_unique_index' => (
 #===================================
-    isa     => ES_UniqueKey,
+    isa     => Str,
     is      => 'ro',
     lazy    => 1,
-    builder => '_build_es_unique',
+    builder => '_build_unique_index',
 );
 
 #===================================
@@ -139,22 +154,17 @@ has 'current_scope' => (
 );
 
 #===================================
-sub BUILD        { shift->doc_class_wrappers }
 sub _build_store { $_[0]->store_class->new( es => $_[0]->es ) }
-sub _build_es    { Search::Elasticsearch::Compat->new }
+sub _build_es { Search::Elasticsearch->new }
 #===================================
 
 #===================================
-sub _build_es_unique {
+sub _build_unique_index {
 #===================================
     my $self  = shift;
     my $index = Class::MOP::class_of($self)->unique_index;
-    my $uniq  = ElasticSearchX::UniqueKey->new(
-        es    => $self->es,
-        index => $index
-    );
-    $uniq->bootstrap;
-    return $uniq;
+    $self->store->bootstrap_uniques( index => $index );
+    return $index;
 }
 
 #===================================
@@ -456,9 +466,12 @@ sub _update_unique_keys {
         $new{$unique_key} = $new if length $new;
     }
 
-    my $uniq = $self->es_unique;
+    my $uniq  = $self->_unique_index;
+    my $store = $self->store;
 
-    if ( my %failed = $uniq->multi_create(%new) ) {
+    if ( my %failed
+        = $store->create_unique_keys( index => $uniq, keys => \%new ) )
+    {
         if ($on_unique) {
             $on_unique->( $doc, \%failed );
             return;
@@ -468,8 +481,12 @@ sub _update_unique_keys {
 
     }
     return {
-        commit   => sub { $uniq->multi_delete(%old); },
-        rollback => sub { $uniq->multi_delete(%new); }
+        commit => sub {
+            $store->delete_unique_keys( index => $uniq, keys => \%old );
+        },
+        rollback => sub {
+            $store->delete_unique_keys( index => $uniq, keys => \%new );
+        },
     };
 }
 
@@ -481,10 +498,10 @@ sub _handle_error {
 
     die $error
         unless $on_conflict
-        and $error =~ /\[Conflict\]/;
+        and $error->is('Conflict');
 
     my $new;
-    if ( my $current_version = $error->{-vars}{current_version} ) {
+    if ( my $current_version = $error->{vars}{current_version} ) {
         my $uid = Elastic::Model::UID->new(
             %{ $original->uid->read_params },
             version    => $current_version,
@@ -528,7 +545,7 @@ sub _delete_unique_keys {
 #===================================
     my ( $self, $uid ) = @_;
 
-    my $doc = $self->get_doc( uid => $uid, ignore_missing => 1 )
+    my $doc = $self->get_doc( uid => $uid, ignore => 404 )
         or return $noops;
 
     my $meta = Class::MOP::class_of($doc);
@@ -540,9 +557,15 @@ sub _delete_unique_keys {
         my $old = $doc->_source->{$key};
         $old{ $uniques->{$key} } = $old if length $old;
     }
-    my $uniq = $self->es_unique;
+    my $uniq  = $self->_unique_index;
+    my $store = $self->store;
     return {
-        commit => sub { $uniq->multi_delete(%old) }
+        commit => sub {
+            $store->delete_unique_keys(
+                index => $uniq,
+                keys  => \%old
+            );
+        },
     };
 }
 
@@ -618,8 +641,7 @@ sub map_class {
         _timestamp        => { enabled => 1, path => 'timestamp' },
         numeric_detection => 1,
     );
-
-    $mapping{_source}{compress} = 1;
+    delete $mapping{type};
     return \%mapping;
 }
 
@@ -639,13 +661,13 @@ Elastic::Model::Role::Model - The role applied to your Model
 
 =head1 VERSION
 
-version 0.28
+version 0.50
 
 =head1 SYNOPSIS
 
     use MyApp;
 
-    my $es         = Search::Elasticsearch::Compat->new( servers => 'es.domain.com:9200' );
+    my $es         = Search::Elasticsearch->new( nodes => 'es.domain.com:9200' );
     my $model      = MyApp->new( es => $es );
 
     my $namespace  = $model->namespace('myapp');
@@ -672,12 +694,12 @@ See L<Elastic::Model> for more about how to setup your Model class.
 =head2 new()
 
 Usually, the only parameter that you need to pass to C<new()> is C<es>,
-which contains your L<Search::Elasticsearch::Compat> connection.
+which contains your L<Search::Elasticsearch> connection.
 
-    $es    = Search::Elasticsearch::Compat->new( servers => 'es1.domain.com:9200' );
+    $es    = Search::Elasticsearch->new( nodes => 'es1.domain.com:9200' );
     $model = MyApp->new( es => $es );
 
-If the C<es> parameter is omitted, then it will default to a L<Search::Elasticsearch::Compat>
+If the C<es> parameter is omitted, then it will default to a L<Search::Elasticsearch>
 connection to C<localhost:9200>.
 
     $model = MyApp->new();   # localhost:9200
@@ -745,7 +767,7 @@ Normally, you want to use L<Elastic::Model::Domain/"get()"> rather than this
 method.
 
     $doc = $model->get_doc(uid => $uid);
-    $doc = $model->get_doc(uid => $uid, ignore_missing => 1, ...);
+    $doc = $model->get_doc(uid => $uid, ignore => 404, ...);
 
 C<get_doc()> tries to retrieve the object corresponding to the
 L<$uid|Elastic::Model::UID>, first from the L</current_scope()> (if there is one)
@@ -763,7 +785,7 @@ Any other args are passed on to L<Elastic::Model::Store/get_doc()>.
 =head3 get_doc_source()
 
     $doc = $model->get_doc_source(uid => $uid);
-    $doc = $model->get_doc_source(uid => $uid, ignore_missing => 1, ...);
+    $doc = $model->get_doc_source(uid => $uid, ignore => 404, ...);
 
 Calls L<Elastic::Model::Store/"get_doc()"> and returns the raw source hashref
 as stored in Elasticsearch for the doc with the corresponding
@@ -801,7 +823,7 @@ L<Elastic::Model::Role::Doc/on_unique> parameters.
 
 =head3 delete_doc()
 
-    $uid = $model->delete_doc(uid => $uid, ignore_missing => 1, ...)
+    $uid = $model->delete_doc(uid => $uid, ignore => 404, ...)
 
 Calls L<Elastic::Model::Store/delete_doc()> and returns the updated
 L<Elastic::Model::UID> object. Throws an error if it doesn't exist.
@@ -840,8 +862,9 @@ of multiple docs in batches.
 
     $bulk = $model->bulk(
         size        => 1000,
-        on_conflict => sub {....},
-        on_error    => sub {....}
+        on_conflict => sub {...},
+        on_error    => sub {...},
+        on_success  => sub {...}
     );
 
 =head2 Miscellaneous
@@ -872,14 +895,7 @@ known to the model.
 
     $es = $model->es
 
-Returns the L<Search::Elasticsearch::Compat> instance that was passed to L</"new()">.
-
-=head3 es_unique
-
-    $uniq = $model->es_unique
-
-Returns the L<ElasticSearchX::UniqueKey> instance pointing to the index
-specified with L<has_unique_index|Elastic::Model/Custom unique key index>.
+Returns the L<Search::Elasticsearch> instance that was passed to L</"new()">.
 
 =head3 store
 
