@@ -1,11 +1,11 @@
 package Elastic::Model::Role::Results;
-$Elastic::Model::Role::Results::VERSION = '0.28';
+$Elastic::Model::Role::Results::VERSION = '0.50';
 use Carp;
 use Moose::Role;
 
 with 'Elastic::Model::Role::Iterator';
 
-use MooseX::Types::Moose qw(HashRef Int Num CodeRef);
+use MooseX::Types::Moose qw(HashRef Int Num CodeRef Bool);
 use namespace::autoclean;
 
 #===================================
@@ -42,6 +42,25 @@ has 'facets' => (
     handles => { facet => 'get' }
 );
 
+#===================================
+has 'aggs' => (
+#===================================
+    isa     => HashRef,
+    traits  => ['Hash'],
+    is      => 'ro',
+    writer  => '_set_aggs',
+    handles => { agg => 'get' }
+);
+
+#===================================
+has 'is_partial' => (
+#===================================
+    isa     => Bool,
+    is      => 'ro',
+    lazy    => 1,
+    builder => '_build_is_partial',
+);
+
 #===================================
 has '_as_result' => (
 #===================================
@@ -98,12 +117,26 @@ has '_as_partials' => (
 
 no Moose;
 
+#===================================
+sub _build_is_partial {
+#===================================
+    my $self = shift;
+    return exists $self->search->{_source};
+}
+
 #===================================
 sub _as_result_builder {
 #===================================
     my $self         = shift;
     my $result_class = $self->model->result_class;
-    sub { $_[0] && $result_class->new( result => $_[0] ) }
+    my $is_partial   = $self->is_partial;
+    sub {
+        $_[0]
+            && $result_class->new(
+            result     => $_[0],
+            is_partial => $is_partial
+            );
+        }
 }
 
 #===================================
@@ -111,21 +144,25 @@ sub _as_results_builder {
 #===================================
     my $self         = shift;
     my $result_class = $self->model->result_class;
+    my $is_partial   = $self->is_partial;
     sub {
-        map { $result_class->new( result => $_ ) } @_;
+        map { $result_class->new( result => $_, is_partial => $is_partial ) }
+            @_;
     };
 }
 
 #===================================
 sub _as_object_builder {
 #===================================
-    my $self  = shift;
-    my $model = $self->model;
+    my $self       = shift;
+    my $model      = $self->model;
+    my $is_partial = $self->is_partial;
     sub {
         my $raw = shift or return;
         $raw->{_object} ||= do {
             my $uid = Elastic::Model::UID->new_from_store($raw);
-            $model->get_doc( uid => $uid, source => $raw->{_source} );
+            my $source = $is_partial ? undef : $raw->{_source};
+            $model->get_doc( uid => $uid, source => $source );
         };
     };
 }
@@ -133,13 +170,15 @@ sub _as_object_builder {
 #===================================
 sub _as_objects_builder {
 #===================================
-    my $self = shift;
-    my $m    = $self->model;
+    my $self       = shift;
+    my $m          = $self->model;
+    my $is_partial = $self->is_partial;
     sub {
         map {
             $_->{_object} ||= do {
                 my $uid = Elastic::Model::UID->new_from_store($_);
-                $m->get_doc( uid => $uid, source => $_->{_source} );
+                my $source = $is_partial ? undef : $_->{_source};
+                $m->get_doc( uid => $uid, source => $source );
             };
         } @_;
     };
@@ -156,7 +195,7 @@ sub _as_partial_builder {
             my $uid = Elastic::Model::UID->new_partial($raw);
             $model->new_partial_doc(
                 uid            => $uid,
-                partial_source => $raw->{fields}->{_partial_doc}
+                partial_source => $raw->{_source}
             );
             }
 
@@ -174,7 +213,7 @@ sub _as_partials_builder {
                 my $uid = Elastic::Model::UID->new_partial($_);
                 $m->new_partial_doc(
                     uid            => $uid,
-                    partial_source => $_->{fields}->{_partial_doc}
+                    partial_source => $_->{_source}
                 );
                 }
         } @_;
@@ -277,7 +316,7 @@ Elastic::Model::Role::Results - An iterator role for search results
 
 =head1 VERSION
 
-version 0.28
+version 0.50
 
 =head1 DESCRIPTION
 
@@ -314,6 +353,15 @@ are sorting by a field other than C<_score> then you will need
 to set L<Elastic::Model::View/track_scores> to true to retrieve the
 L</max_score>.
 
+=head2 aggs
+
+=head2 agg
+
+    $aggs = $results->aggs
+    $agg  = $results->agg($agg_name)
+
+Aggregation results, if any were requested with L<Elastic::Model::View/aggs>.
+
 =head2 facets
 
 =head2 facet
@@ -336,6 +384,13 @@ An array ref containing all of the data structures that we can iterate over.
 Contains the hash ref of the search request passed to
 L<Elastic::Model::Role::Store/search()>
 
+=head2 is_partial
+
+    $bool = $result->is_partial
+
+Returns C<true> or C<false> to indicate whether the specified search
+returns full or partial results.
+
 =head1 WRAPPERS
 
 =head2 as_results()
