@@ -1,5 +1,5 @@
 package Elastic::Model::Trait::Field;
-$Elastic::Model::Trait::Field::VERSION = '0.28';
+$Elastic::Model::Trait::Field::VERSION = '0.50';
 use Moose::Role;
 Moose::Util::meta_attribute_alias('ElasticField');
 
@@ -25,8 +25,8 @@ has 'type' => (
 #===================================
 has 'mapping' => (
 #===================================
-    isa => HashRef [Str],
-    is => 'rw'
+    isa => HashRef,
+    is  => 'rw'
 );
 
 #===================================
@@ -123,20 +123,6 @@ has 'search_quote_analyzer' => (
     is  => 'rw'
 );
 
-#===================================
-has 'omit_norms' => (
-#===================================
-    isa => Bool,
-    is  => 'rw'
-);
-
-#===================================
-has 'omit_term_freq_and_positions' => (
-#===================================
-    isa => Bool,
-    is  => 'rw'
-);
-
 #===================================
 has 'term_vector' => (
 #===================================
@@ -267,7 +253,7 @@ Elastic::Model::Trait::Field - Add Elasticsearch specific keywords to your attri
 
 =head1 VERSION
 
-version 0.28
+version 0.50
 
 =head1 DESCRIPTION
 
@@ -298,9 +284,9 @@ keywords.
 
 =head2 L<multi|Elastic::Manual::Attributes/multi>
 
-=head2 L<index_name|Elastic::Manual::Attributes/index_name>
+=head2 L<index_name|Elastic::Manual::Attributes/index_name> [DEPRECATED]
 
-=head2 L<boost|Elastic::Manual::Attributes/boost>
+=head2 L<boost|Elastic::Manual::Attributes/boost> [DEPRECATED]
 
 =head2 L<null_value|Elastic::Manual::Attributes/null_value>
 
@@ -312,16 +298,10 @@ keywords.
 
 =head2 L<search_quote_analyzer|Elastic::Manual::Attributes/search_quote_analyzer>
 
-=head2 L<omit_norms|Elastic::Manual::Attributes/omit_norms>
-
-=head2 L<omit_term_freq_and_positions|Elastic::Manual::Attributes/omit_term_freq_and_positions>
-
 =head2 L<term_vector|Elastic::Manual::Attributes/term_vector>
 
 =head2 L<format|Elastic::Manual::Attributes/format>
 
-=head2 L<precision_step|Elastic::Manual::Attributes/precision_step>
-
 =head2 L<geohash|Elastic::Manual::Attributes/geohash>
 
 =head2 L<lat_lon|Elastic::Manual::Attributes/lat_lon>
@@ -332,7 +312,7 @@ keywords.
 
 =head2 L<dynamic|Elastic::Manual::Attributes/dynamic>
 
-=head2 L<path|Elastic::Manual::Attributes/path>
+=head2 L<path|Elastic::Manual::Attributes/path> [DEPRECATED]
 
 =head2 L<include_in_parent|Elastic::Manual::Attributes/include_in_parent>
 
