@@ -1,9 +1,8 @@
 package Elastic::Model::Types;
-$Elastic::Model::Types::VERSION = '0.28';
+$Elastic::Model::Types::VERSION = '0.50';
 use strict;
 use warnings;
-use Search::Elasticsearch::Compat();
-use ElasticSearchX::UniqueKey();
+use Search::Elasticsearch();
 
 use MooseX::Types::Moose qw(HashRef ArrayRef Str Bool Num Int Defined Any);
 use MooseX::Types::Structured qw (Dict Optional Map);
@@ -16,7 +15,8 @@ use MooseX::Types -declare => [ qw(
         CoreFieldType
         DynamicMapping
         ES
-        ES_UniqueKey
+        ES_1x
+        ES_90
         FieldType
         GeoPoint
         HighlightArgs
@@ -76,23 +76,22 @@ while ( my $type = shift @enums ) {
     );
 }
 
-#===================================
-class_type ES, { class => 'Search::Elasticsearch::Client::Compat' };
-#===================================
-coerce ES, from HashRef, via { Search::Elasticsearch::Compat->new($_) };
-coerce ES, from Str, via {
-    s/^:/127.0.0.1:/;
-    Search::Elasticsearch::Compat->new( servers => $_ );
-};
-coerce ES, from ArrayRef, via {
-    my @servers = @$_;
-    s/^:/127.0.0.1:/ for @servers;
-    Search::Elasticsearch::Compat->new( servers => \@servers );
-};
+class_type ES_1x, { class => 'Search::Elasticsearch::Client::Direct' };
+class_type ES_90, { class => 'Search::Elasticsearch::Client::0_90::Direct' };
 
 #===================================
-class_type ES_UniqueKey, { class => 'ElasticSearchX::UniqueKey' };
+subtype ES(), as ES_1x | ES_90;
 #===================================
+coerce ES, from HashRef, via { Search::Elasticsearch->new($_) };
+coerce ES, from Str, via {
+    s/^:/127.0.0.1:/;
+    Search::Elasticsearch->new( nodes => $_ );
+};
+coerce ES, from ArrayRef, via {
+    my @nodes = @$_;
+    s/^:/127.0.0.1:/ for @nodes;
+    Search::Elasticsearch->new( servers => \@nodes );
+};
 
 #===================================
 subtype StoreMapping, as enum( [ 'yes', 'no' ] );
@@ -102,23 +101,21 @@ coerce StoreMapping, from Any, via { $_ ? 'yes' : 'no' };
 #===================================
 subtype MultiField, as Dict [
 #===================================
-    type                         => Optional [CoreFieldType],
-    index                        => Optional [IndexMapping],
-    index_name                   => Optional [Str],
-    boost                        => Optional [Num],
-    null_value                   => Optional [Str],
-    analyzer                     => Optional [Str],
-    index_analyzer               => Optional [Str],
-    search_analyzer              => Optional [Str],
-    search_quote_analyzer        => Optional [Str],
-    omit_norms                   => Optional [Bool],
-    omit_term_freq_and_positions => Optional [Bool],
-    term_vector                  => Optional [TermVectorMapping],
-    geohash                      => Optional [Bool],
-    lat_lon                      => Optional [Bool],
-    geohash_precision            => Optional [Int],
-    precision_step               => Optional [Int],
-    format                       => Optional [Str],
+    type                  => Optional [CoreFieldType],
+    index                 => Optional [IndexMapping],
+    index_name            => Optional [Str],
+    boost                 => Optional [Num],
+    null_value            => Optional [Str],
+    analyzer              => Optional [Str],
+    index_analyzer        => Optional [Str],
+    search_analyzer       => Optional [Str],
+    search_quote_analyzer => Optional [Str],
+    term_vector           => Optional [TermVectorMapping],
+    geohash               => Optional [Bool],
+    lat_lon               => Optional [Bool],
+    geohash_precision     => Optional [Int],
+    precision_step        => Optional [Int],
+    format                => Optional [Str],
 
 ];
 
@@ -211,7 +208,7 @@ Elastic::Model::Types - MooseX::Types for general and internal use
 
 =head1 VERSION
 
-version 0.28
+version 0.50
 
 =head1 SYNOPSIS
 
